/*
 *      Task 1 - Receive char through UART
 */
#include <msp430.h>
#include "function.h"

#define DIGIT2ASCII(x)	(x + 48)
#define ASCII2DIGIT(x)	(x - 48)

volatile unsigned char data;	//This data will be printed on display

/*
 * main.c
 */
int main(void) {
    WDTCTL = WDTPW | WDTHOLD;	// Stop watchdog timer

    /* Initialize  7seg display */
    P6DIR |= ~BIT7;				// Segments
    P11DIR |= BIT1;				// First display is selected
    P11OUT &= ~BIT1;			// First display is turned on
    /*Initialize button S4 */
    P2IE |= BIT7;				// Enable interrupt for button S4
    P2IES |= BIT7;				// Falling edge is selected as interrupt source
    /*UART Initialization*/
    P3SEL    |= BIT4 | BIT5;    // Pins 4 and 5 of port 3 are UART pins
    UCA0CTL1 |= UCSWRST;		// USCI enter in reset state
    UCA0CTL1 |= UCSSEL__SMCLK;	// Select clock source
    /*Select boudrate 9200bps
     * From table 36-4 chose values to reach this boudrate
     * */
    UCA0BR0  = 109;
    UCA0MCTL |= UCBRS_2;

    UCA0CTL1 &= ~UCSWRST;		// USCI leaves reset state

    __bis_SR_register(GIE);		// Enable global interrupt

    while (1) {
    	while (!(UCA0IFG & UCRXIFG));	// Wait while data isn't received
    	data = ASCII2DIGIT(UCA0RXBUF);	// When data is received, read received data
    	WriteLed(data);					// Convert from ASCII to Digit
    }
	
	//return 0;
}

/*
 * PORT 2 Interrupt Service routine
 */
void __attribute__((interrupt(PORT2_VECTOR))) port2handler(void)
{
    __delay_cycles(10000); //Debounce period
    //Check interrupt source
    if (P2IFG & BIT7) {
        //Check if button still pressed
        if (!(P2IN & BIT7)) {
            UCA0TXBUF = DIGIT2ASCII(data);      // Send data through UART by write data in TXBUFER
        }
        P2IFG &= ~BIT7;                     // Clear button interrupt pin
    }
}
